Substitution plan
=================

In addition to the `smart plan`, substitutions can be
displayed as a traditional substitution plan. The substitution
plan lists all changes made to the regular plan, on a
daily basis, as a table.

View in AlekSIS
~~~~~~~~~~~~~~~

In AlekSIS, the substitution plan is available from the menu under
`Timetable → Substitutions`. This function provides a browsable list,
where substitution plans can be navigated by week.

.. image:: ../_static/substitutions.png
  :width: 600
  :alt: Substitutions

Print view
~~~~~~~~~~

Like for the regular timetable, the substitution plan can be
printed (as a PDF file), to make hardcopies, or to display it
on digital signage.

.. image:: ../_static/substitutions_print.png
  :width: 600
  :alt: Print view of substitutions